Research
========

.. toctree::

   notebooks/research/discrete_comparison
   notebooks/research/geometric_decoders
   notebooks/research/linear_model_reduction
   notebooks/research/sampling_high_dimensional_vectors
